@@ -2,9 +2,9 @@ import logging
 import os
 import sys
 
-log = logging.getLogger(__name__)
+from jms_utils import FROZEN
 
-FROZEN = getattr(sys, u'frozen', False)
+log = logging.getLogger(__name__)
 
 
 class ChDir(object):
